require 'spec_helper'

describe SugarPNG do
  describe "text" do
    it "greets me" do
      text = "Hello world!"
      ascii = <<-EOF.strip.split("\n").map(&:strip).join("\n")
        .............................................................................................
        .............................................................................................
        .............................................................................................
        ......................................................................................#......
        .#....#............##......##..............................................##.........#.....#
        .#....#.............#.......#...............................................#.........#.....#
        .#....#...####......#.......#.....####...........#.....#..####...#.###......#.....###.#.....#
        .#....#..#....#.....#.......#....#....#..........#..#..#.#....#..##...#.....#....#...##.....#
        .######..#....#.....#.......#....#....#..........#..#..#.#....#..#....#.....#....#....#.....#
        .#....#..######.....#.......#....#....#..........#..#..#.#....#..#..........#....#....#.....#
        .#....#..#..........#.......#....#....#..........#..#..#.#....#..#..........#....#....#.....#
        .#....#..#..........#.......#....#....#..........#..#..#.#....#..#..........#....#....#......
        .#....#..#....#.....#.......#....#....#..........#..#..#.#....#..#..........#....#...##.....#
        .#....#...####....#####...#####...####............##.##...####...#........#####...###.#.....#
      EOF
      SugarPNG.new do |img|
        img.text text, :color => :white

        img = ZPNG::Image.new(img.to_s)
        img.to_ascii('.#').should == ascii
        img.width.should == 93
        img.height.should == 14
        img.pixels.uniq.sort.should == [SugarPNG::Color::WHITE, SugarPNG::Color::TRANSPARENT].sort
      end
    end

    it "offsets" do
      text = "Hello"
      ascii = <<-EOF.strip.split("\n").map(&:strip).join("\n")
        ............................................
        ............................................
        ............................................
        ............................................
        ............................................
        ............................................
        ............................................
        ......#....#............##......##..........
        ......#....#.............#.......#..........
        ......#....#...####......#.......#.....####.
        ......#....#..#....#.....#.......#....#....#
        ......######..#....#.....#.......#....#....#
        ......#....#..######.....#.......#....#....#
        ......#....#..#..........#.......#....#....#
        ......#....#..#..........#.......#....#....#
        ......#....#..#....#.....#.......#....#....#
        ......#....#...####....#####...#####...####.
      EOF
      SugarPNG.new do |img|
        img.text text, :color => :white, :x => 5, :y => 3

        img = ZPNG::Image.new(img.to_s)
        img.to_ascii('.#').should == ascii
        img.width.should == 44
        img.height.should == 17
        img.pixels.uniq.sort.should == [SugarPNG::Color::WHITE, SugarPNG::Color::TRANSPARENT].sort
      end
    end

    it "multilines" do
      ascii = <<-EOF.strip.split("\n").map(&:strip).join("\n")
        .............................................
        .............................................
        .............................................
        .............................................
        .#....#............##......##................
        .#....#.............#.......#................
        .#....#...####......#.......#.....####.......
        .#....#..#....#.....#.......#....#....#......
        .######..#....#.....#.......#....#....#......
        .#....#..######.....#.......#....#....#......
        .#....#..#..........#.......#....#....#......
        .#....#..#..........#.......#....#....#......
        .#....#..#....#.....#.......#....#....#......
        .#....#...####....#####...#####...####.......
        .............................................
        .............................................
        .............................................
        .............................................
        .............................................
        ......................................#......
        ...........................##.........#.....#
        ............................#.........#.....#
        .#.....#..####...#.###......#.....###.#.....#
        .#..#..#.#....#..##...#.....#....#...##.....#
        .#..#..#.#....#..#....#.....#....#....#.....#
        .#..#..#.#....#..#..........#....#....#.....#
        .#..#..#.#....#..#..........#....#....#.....#
        .#..#..#.#....#..#..........#....#....#......
        .#..#..#.#....#..#..........#....#...##.....#
        ..##.##...####...#........#####...###.#.....#
      EOF

      data = SugarPNG.new do
        color :red
        text "Hello\nworld!"
      end.export

      img = ZPNG::Image.new(data)
      img.to_ascii('.####').should == ascii
      img.save "out.png"
      img.width.should == 45
      img.height.should == 30
      img.pixels.uniq.sort.should == [SugarPNG::Color::RED, SugarPNG::Color::TRANSPARENT].sort
    end
  end
end
